@@ -26,18 +26,13 @@ def setup():
     source_format = args.source_format
     destination = args.destination
     des_format = args.format
-    print(args.conf_file)
     if args.conf_file is not None:  # and args.conf_file == "config.py"
         data = {}
         try:
-            with open("config.py", 'r') as cf:
+            with open(args.conf_file, 'r') as cf:
                 for line in cf:
                     line = line.replace("\n", "")
-                    # print(line)
-                    # print(re.findall(r"[^= \"\']+", line))
                     (key, value) = re.findall(r"[^= \"\']+", line)
-                    print(key)
-                    print(value)
                     data[key] = value
         except IOError as e:
             print(e)
@@ -81,12 +76,14 @@ def convert(source: str, source_format: str, destination: str, des_format):
         with open(source, 'r') as src:
             if source_format not in formats.keys():
                 raise ValueError(f'File should contain a format: {formats.keys()}')
-            if source_format != des_format.upper():
+            if source_format != des_format:
+                print(f'From {source}({source_format})...')
                 source_serializer = formats[source_format].create_serializer()
                 serializer = formats[des_format].create_serializer()
                 with open(destination, 'w') as dst:
                     data = source_serializer.loads(src.read())
                     dst.write(serializer.dumps(data))
+                    print(f'To {destination}({des_format})      Completed!')
             else:
                 raise ValueError(f'Source and destination format shouldn\'t be same')
     except IOError:
